@@ -4,11 +4,7 @@
 #include <sys/stat.h>
 #include <sys/syscall.h>
 
-#ifndef __NR_lstat
-
 int lstat(const char *path, struct stat *buf)
 {
 	return fstatat(AT_FDCWD, path, buf, AT_SYMLINK_NOFOLLOW);
 }
-
-#endif  /* __NR_lstat  */
